@@ -47,7 +47,7 @@ int i;
       key = copy(s,1,i-1);
       //printf("%s -> %s",s(),key());
 
-      if(key!="")
+      if(!key.isEmpty())
         {
         const char *Semicolon = strchr(key(),';');
         if(Semicolon!=NULL)
@@ -70,7 +70,7 @@ int i;
       
       if(s[0]=='[')				//new key was found
       	   {
-           if(code!="") result.Add(key,code);
+           if(!code.isEmpty()) result.Add(key,code);
            for(i=length(s)-1; i>1; i--)
                {
                if(s[i]==']') break;
@@ -78,7 +78,7 @@ int i;
            if(s[i]==']')
              {
              key = copy(s,1,i-1);
-             if(key!="")
+             if(!key.isEmpty())
                {
                const char *Semicolon = strchr(key(),';');
                if(Semicolon!=NULL)
@@ -99,7 +99,7 @@ int i;
            break;
            }
       else {
-      	   if(code!="") code+='\n';
+      	   if(!code.isEmpty()) code+='\n';
       	   code+=s;
            }
       }
@@ -107,7 +107,7 @@ int i;
 
   fclose(F);
 
-  if(key!="" && code!="") result.Add(key,code);
+  if(!key.isEmpty() && !code.isEmpty()) result.Add(key,code);
 
 return result;
 }
