@@ -872,6 +872,16 @@ void TImgConvStatus::ClearBrushes(void)
 }
 
 
+void FixLineStyle(const unsigned Flags, vecPen *pPen)
+{
+  if((Flags & WPG2_Transform::WPG2_FRM) == 0)
+      pPen->LineStyle=0;	// Disable object fill.
+  else
+      {if(pPen->LineStyle==0) pPen->LineStyle=1;}
+}
+
+
+
 /** Processing one token inside separate procedure allows to recurse tokens. 
  * @param[in,out]	bbx	  Bounding box [WPU].
  * @param[in,out]	NewObjectPos	File position of new object. */
@@ -1154,9 +1164,7 @@ vecResizeCTM TRx;
                       pVecPoly->AttribFromPSS(PSS);  
                       pVecPoly->Close = true;
                       pVecPoly->Outline = TRx.Flags&WPG2_Transform::WPG2_FRM;
-                      if((TRx.Flags & WPG2_Transform::WPG2_FRM) == 0) pVecPoly->LineStyle=0;	// Disable object fill.
-                      else
-                          {if(pVecPoly->LineStyle==0) pVecPoly->LineStyle=1;}                      
+		      FixLineStyle(TRx.Flags, pVecPoly);
                       pVecPoly->Transform(vecResizeXY(WPGu2PSu(1)));
                       VectList.AddObject(pVecPoly);
                       }
@@ -1188,7 +1196,7 @@ vecResizeCTM TRx;
                   pVecCurve->AttribFromPSS(PSS);
                   pVecCurve->Transform(vecResizeXY(WPGu2PSu(1)));		  
                   if(TRx.Flags&WPG2_Transform::WPG2_FILL) pVecCurve->Filled=true;	// check Fill
-                  if(TRx.Flags&WPG2_Transform::WPG2_FRM) pVecCurve->LineStyle=0;	// Frame flags
+		  FixLineStyle(TRx.Flags, pVecCurve);
 		  VectList.AddObject(pVecCurve);
 		  break;
 		  }
@@ -1248,10 +1256,7 @@ vecResizeCTM TRx;
 
                   pVecEllipse->AttribFromPSS(PSS);
                   if((TRx.Flags & WPG2_Transform::WPG2_FILL) == 0) pVecEllipse->BrushStyle=0;	// Disable object fill.
-                  if((TRx.Flags & WPG2_Transform::WPG2_FRM) == 0) pVecEllipse->LineStyle=0;	// Disable object fill.
-                  else
-                    {if(pVecEllipse->LineStyle==0) pVecEllipse->LineStyle=1;}
-
+                  FixLineStyle(TRx.Flags, pVecEllipse);
 		  //if(b) {pVecEllipse->FillColor.Red=0x80;b=false;}
                   VectList.AddObject(pVecEllipse);
 		  break;
@@ -1513,7 +1518,7 @@ vecResizeCTM TRx;
 		default:if(cq->err && Pattern>=32)
 			  {
                           cq->perc.Hide();
-		          fprintf(cq->err,_("Warning: Unexpected hatch pattern %d."),Pattern); 
+		          fprintf(cq->err,_("\nWarning: Unexpected hatch pattern %d."),Pattern); 
                           }
 			PSS.FillPattern=1;
 			break;
@@ -2374,7 +2379,7 @@ bool bFileIsOK = false;
   ss = GetExtension(Filename);
   if(ss!=NULL) if(*ss!=0) FileExtension=ToUpper(ss+1);
 
-  if(NewFilename!="")
+  if(!NewFilename.isEmpty())
      for(i=StrLen(OutputDir);i<length(NewFilename);i++)
 	{
 	if(NewFilename[i]==' ' || NewFilename[i]=='#' || NewFilename[i]=='%' || NewFilename[i]=='$' || NewFilename[i]=='*')
@@ -2402,11 +2407,12 @@ bool bFileIsOK = false;
 	{
 	for(i=0; i<length(ImgInputDirs); i++)
 	  {
-	  if(!CopyFile(NewFilename,(string(ImgInputDirs[i])+Filename)())) 
-            {
-            bFileIsOK = true;
-            goto FileIsOK;
-            }
+	    string tmp = string(ImgInputDirs[i]) + Filename;
+	    if(!CopyFile(NewFilename,tmp))
+              {
+              bFileIsOK = true;
+              goto FileIsOK;
+              }
 	  }
 	}
      }
