@@ -16,7 +16,7 @@ class AbstractTransformXY;
 float *LoadPoints(TconvertedPass1 *cq, int n, FloatBBox &bbx, AbstractTransformXY *TRx=NULL,bool Precision=false);
 
 
-void AddCharacterToContainer(TextContainer *pTextCont, WORD WchI, CpTranslator *PsNativeCP, CpTranslator *PsNativeSym, 
+void AddCharacterToContainer(TextContainer *pTextCont, WORD WchI, const CpTranslator *PsNativeCP, const CpTranslator *PsNativeSym, 
 		TconvertedPass1 *cq, PS_State &PSS);
 
 #endif // __IMAGES_H__
\ No newline at end of file
