@@ -63,6 +63,17 @@ PS_State::PS_State(void)
   PS_StateC *pPS_StateC = (PS_StateC *)this;
   memset(pPS_StateC,0,sizeof(PS_StateC));
   memset(&PaperBackground, 0, sizeof(PaperBackground));
+  pPalette = NULL;
+}
+
+
+PS_State::~PS_State()
+{
+  if(pPalette != NULL)
+  {
+    if(pPalette->UsageCount--<=1) delete pPalette;
+    pPalette = NULL;
+  }
 }
 
 
@@ -71,10 +82,25 @@ PS_State & PS_State::operator=(const PS_State & OrigPSS)
   memcpy((PS_StateC*)this, (PS_StateC*)&OrigPSS, sizeof(PS_StateC));
   PaperBackground = OrigPSS.PaperBackground;
   FontName = OrigPSS.FontName;
+  AttachPalette(OrigPSS.pPalette);
 return *this;
 }
 
 
+void PS_State::AttachPalette(APalette *NewPalette)
+{
+  if(pPalette!=NULL)			// Detach previously attached raster
+  {
+    if(pPalette->UsageCount--<=1) delete pPalette;
+    pPalette = NULL;
+  }
+  if(NewPalette!=NULL)			// Attach raster now
+  {
+    pPalette=NewPalette; pPalette->UsageCount++;
+  }
+}
+
+
 
 ////////////////////////////////////
 
@@ -206,6 +232,31 @@ void vecFont::prepExport(PS_State *PSS) const
   }
 }
 
+
+attrPalette::attrPalette(APalette *iniPalette)
+{
+  pPalette = iniPalette;
+  if(pPalette!=NULL) pPalette->UsageCount++;
+}
+
+
+attrPalette::~attrPalette()
+{
+  if(pPalette != NULL)
+  {
+    if(pPalette->UsageCount--<=1) delete pPalette;
+    pPalette = NULL;
+  }
+}
+
+
+void attrPalette::prepExport(PS_State *PSS) const
+{
+  if(PSS==NULL) return;
+  PSS->AttachPalette(pPalette);
+}
+
+
 ////////////////////////////////////
 
 vecTransform::vecTransform(void)
@@ -220,7 +271,7 @@ bool vecTransform::ApplyTransform(string &s)
 {
 bool ContextSaved = false;
 
-  if(fabs(RotAngle)>1e-10)
+  if(fabs(RotAngle) > 1e-10)
   {
     s.cat_printf("\ngsave\n%2.2f %2.2f translate\n%2.2f rotate\n%2.2f %2.2f translate",
 		 CenterX,CenterY, RotAngle, -CenterX,-CenterY);
@@ -274,7 +325,7 @@ VectorEllipse::~VectorEllipse()
 
 temp_string VectorEllipse::Export2EPS(PS_State *PSS) const
 {
-temp_string str;
+string str;
 
   if(PSS != NULL)
   {
@@ -304,7 +355,7 @@ temp_string str;
 
   if(ContextSaved) str += "\ngrestore";
 
-return str;
+return temp_string(str);
 }
 
 
@@ -366,7 +417,7 @@ unsigned VectorRectangle::isInside(float xp, float yp) const
 
 temp_string VectorRectangle::Export2EPS(PS_State *PSS) const
 {
-temp_string str;
+string str;
 
   if(PSS != NULL)
   {
@@ -396,7 +447,7 @@ temp_string str;
 
   if(ContextSaved) str += "\ngrestore";
 
-return str;
+return temp_string(str);
 }
 
 
@@ -448,7 +499,7 @@ bool ContextSaved = false;
   if(fabs(Hradius)<1e-5 || fabs(Vradius)<1e-5)
       return VectorRectangle::Export2EPS(PSS);
 
-  temp_string PSData;
+  string PSData;
 
   if(PSS != NULL)
   {
@@ -482,7 +533,7 @@ bool ContextSaved = false;
  PSData+="\nclosepath";
  FillObjectPS(RightRect, LeftRect, Ty*Y_ll, Ty*Y_ur,PSData,PSS);
  if(ContextSaved) PSData+="\ngrestore";
- return PSData;
+ return temp_string(PSData);
 }
 
 
@@ -511,8 +562,8 @@ VectorPolygon::~VectorPolygon()
 
 temp_string VectorPolygon::Export2EPS(PS_State *PSS) const
 {
-temp_string str;
-  if(Points==NULL || CountPoints<=0) return str;
+string str;
+  if(Points==NULL || CountPoints<=0) return temp_string();
 
   if(PSS != NULL)
   {
@@ -556,7 +607,7 @@ temp_string str;
   
   FillObjectPS(MinPolyX,MaxPolyX,MinPolyY,MaxPolyY,str,PSS);
   
-  return str;
+  return temp_string(str);
 }
 
 
@@ -769,13 +820,13 @@ int OriUpDn = 0;
 
 temp_string VectorCurve::Export2EPS(PS_State *PSS) const
 {
-temp_string str;
+string str;
 float MinPolyX,MaxPolyX,MinPolyY,MaxPolyY;
 bool ExtraStartup;
 float *p = Points;
 
 	// There must be at least two points for the line.
-  if(Points==NULL || CountPoints<=1) return str;
+  if(Points==NULL || CountPoints<=1) return temp_string();
 
   if((CountPoints-1)%3 == 0) 
   {
@@ -846,7 +897,7 @@ float *p = Points;
     if(Close) str += "\nclosepath";
     str += "\nstroke"; 
   }
-  return str;
+  return temp_string(str);
 }
 
 
@@ -887,9 +938,9 @@ VectorLine::~VectorLine()
 
 temp_string VectorLine::Export2EPS(PS_State *PSS) const
 {
-temp_string str;
+string str;
 	// There must be at least two points for the line.
-  if(Points==NULL || CountPoints<=1) return str;
+  if(Points==NULL || CountPoints<=1) return temp_string();
 
   if(PSS != NULL)
   {    
@@ -907,7 +958,7 @@ temp_string str;
   }
   if(Close) str += "\nclosepath";
   str += "\nstroke"; 
-  return str;
+  return temp_string(str);
 }
 
 
@@ -963,7 +1014,7 @@ VectorObject *IterObject = FirstObject;
 
 temp_string VectorList::Export2EPS(PS_State *PSS) const
 {
-temp_string str;
+string str;
 VectorObject *IterObject = FirstObject;
 
   while(IterObject!=NULL)
@@ -971,7 +1022,7 @@ VectorObject *IterObject = FirstObject;
     str += IterObject->Export2EPS(PSS);
     IterObject = IterObject->NextObject;
   }
-  return str;
+  return temp_string(str);
 }
 
 
@@ -1023,7 +1074,7 @@ VectorObject *IterObject = FirstObject;
   if(F==NULL) return;
   while(IterObject!=NULL)
   {
-    temp_string StrTmp(IterObject->Export2EPS(PSS));
+    string StrTmp(IterObject->Export2EPS(PSS));
     if(StrTmp.length() > 0)
       fputs(StrTmp(), F);
     IterObject = IterObject->NextObject;
@@ -1113,7 +1164,7 @@ void AppendShow(string &str)
 
 temp_string TextContainer::Export2EPS(PS_State *PSS) const
 {
-temp_string str;
+string str;
 RGB_Record BkTextColor;
 float CurPosX = PosX;
 float CurPosY = PosY;
@@ -1219,7 +1270,7 @@ const bool TextRotated = fabs(NormAngleDEG(FontOrientation)) > 0.01;
     }
   }
 
-return str;
+return temp_string(str);
 }
 
 
@@ -1317,7 +1368,7 @@ static void CheckAccent(unsigned & Feature, const char *PS_text)
 
 void TextContainer::FeaturesEPS(unsigned & Feature) const
 {
-  CheckAccent(Feature, Export2EPS());
+  CheckAccent(Feature, Export2EPS()());
 }
 
 
