@@ -38,6 +38,7 @@ typedef struct
 	char FillPattern;
 	BYTE LineStyle;
         BYTE PolyFillMode;		///< 0-standard; 1-alternating
+	BYTE TextAllign;
 
 	float LineWidth;
 	RGB_Record FillColor;
@@ -55,10 +56,13 @@ class PS_State: public PS_StateC
 {
 public:
 	PS_State(void);
+	~PS_State(void);
 	PS_State &operator=(const PS_State & OrigPSS);
+	void AttachPalette(APalette *NewPalette);
 
 	RGB_Record PaperBackground;
 	string FontName;
+	APalette *pPalette;
 };
 
 
@@ -141,6 +145,24 @@ public:
 };
 
 
+class FakeAttr: public VectorAttribute
+{
+public:
+  virtual void prepExport(PS_State *PSS) const {};
+};
+
+
+class attrPalette: public VectorAttribute
+{
+public:
+  APalette *pPalette;
+
+  attrPalette(APalette *iniPalette);
+  virtual ~attrPalette();
+  virtual void prepExport(PS_State *PSS) const;
+};
+
+
 class vecTransform
 {
 public:
