@@ -1552,14 +1552,14 @@ string temp_filename;
   if(fib.fcMin<ActualPos || fib.fcMin>fib.fcMac)
 	{
 	if(err != NULL)
-	  {perc.Hide();fprintf(err,_("\nError: FIB.fcMin is corrupted %ld!"),fib.fcMin);}
-	fib.fcMin=ActualPos;
+	  {perc.Hide();fprintf(err,_("\nError: FIB.fcMin is corrupted %ld!"), (long)fib.fcMin);}
+	fib.fcMin = ActualPos;
 	}
   if(fib.fcMac>fsize)
 	{
 	if(err != NULL)
-	  {perc.Hide();fprintf(err,_("\nError: FIB.fcMac is bigger than file size %ld!"),fib.fcMac);}
-	fib.fcMac=fsize;
+	  {perc.Hide();fprintf(err,_("\nError: FIB.fcMac is bigger than file size %ld!"), (long)fib.fcMac);}
+	fib.fcMac = fsize;
 	}
 
 //printf("%s\n",wvAutoCharset(&cq));
