@@ -267,7 +267,7 @@ int i;
  if(ch=='/' || ch=='\\')
          RelativeFigDir = copy(RelativeFigDir,0,StrLen(RelativeFigDir)-1);
 
- if(wpd_filename=="") return;
+ if(wpd_filename.isEmpty()) return;
 
  if((i=GetPathEnd(wpd_filename())) > 0)
     {
@@ -320,8 +320,8 @@ char typ,oldtyp;
  if(length(var)>0) Noclobber=true;
 
  var = getenv("wp2latex");
- if(var=="") var = getenv("WP2LATEX");
- if(var=="") return;
+ if(var.isEmpty()) var = getenv("WP2LATEX");
+ if(var.isEmpty()) return;
 
  oldtyp=0;
  for(i=0;i<length(var);i++)
@@ -364,7 +364,7 @@ while(!feof(F))
    {
    fGets2(F,s);
    s.trim();
-   if(s=="") continue;
+   if(s.isEmpty()) continue;
 /*   if(s=="[WPUserChars]")
 	{
 	Section=1;
@@ -384,7 +384,7 @@ while(!feof(F))
 	       while(isdigit(s[0]))
 		   {
 		   s=copy(s,1,length(s)-1);
-		   if(s=="") break;
+		   if(s.isEmpty()) break;
 		   }
 	       s=trim(s);
 	       if(UserWPCharSet==NULL)
@@ -1970,12 +1970,12 @@ int p;
       }
 
 
-    if(wpd_filename == "")
+    if(wpd_filename.isEmpty())
        {
        wpd_filename = name;
        continue;
        }
-    if(latex_filename == "")
+    if(latex_filename.isEmpty())
        {
        latex_filename = name;
        continue;
