@@ -467,7 +467,7 @@ string s;
   Heading();
   printf(_("\nLog file name [%s]: "), chk(LogFile()));
   StrGets(s);
-  if(s != "") LogFile=s;
+  if(!s.isEmpty()) LogFile=s;
 }
 
 
@@ -478,16 +478,16 @@ int p;
 
   Heading();
 
-  if(latex_filename == "")
+  if(latex_filename.isEmpty())
       {
-      if(Interactive && (Verbosing>=1 || wpd_filename==""))
+      if(Interactive && (Verbosing>=1 || wpd_filename.isEmpty()))
          {
 	 printf(_("\nWordPerfect-filename [%s]: "), chk(wpd_filename()));
 	 StrGets(StrName);
-	 if (StrName != "") wpd_filename=StrName;
+	 if(!StrName.isEmpty()) wpd_filename=StrName;
          }
 
-    if(wpd_filename == "")
+    if(wpd_filename.isEmpty())
         { 			  /* No filename entered */
 	RunError(0x200);
         }
@@ -506,16 +506,16 @@ int p;
     if(p<=0) p=length(wpd_filename); //no extension
 
 
-    if(latex_filename == "")
+    if(latex_filename.isEmpty())
           {
 	  latex_filename=copy(wpd_filename,0,p) + ".tex";
 	  }
 
-    if(Interactive && (Verbosing >= 1 || latex_filename == ""))
+    if(Interactive && (Verbosing >= 1 || latex_filename.isEmpty()))
        {
        printf(_("LaTeX-filename [%s]: "), chk(latex_filename()));
        StrGets(StrName);
-       if (StrName != "") latex_filename = StrName;
+       if(!StrName.isEmpty()) latex_filename = StrName;
        }
   }
 
@@ -622,11 +622,11 @@ char str[20];
      AskUser();
      }
    }
-#if defined(POINTER_SIZE) && POINTER_SIZE==32
- if(sizeof(void*)!=4)
+#if defined(POINTER_SIZE)
+ if(8*sizeof(void*)!=POINTER_SIZE)
  {
    Heading();
-   fprintf(err,_("\nFatal: Compillation has been optimised for pointer size 32bits, pointer size is %u!"), 8*sizeof(void*));
+   fprintf(err,_("\nFatal: Compillation has been optimised for pointer size 32bits, pointer size is %ubits!"), 8*sizeof(void*));
    AskUser();
  }
 #endif
@@ -693,7 +693,7 @@ TconvertedPass1 *cqPass1;
   if((wpd = fopen(wpd_filename, "rb")) == NULL)
 	RunError(2,wpd_filename);
 
-  if(FORCE != "")
+  if(!FORCE.isEmpty())
      {
      cqPass1 = GetConverter(FORCE);
      if(cqPass1==NULL)
@@ -707,7 +707,7 @@ TconvertedPass1 *cqPass1;
      {
      CheckFileFormat(wpd,FilForD);
      cqPass1 = GetConverter(FilForD.Converter);
-     if(cqPass1==NULL && force!="")
+     if(cqPass1==NULL && !force.isEmpty())
 	{
 	cqPass1=GetConverter(force);
 	if(cqPass1==NULL)
@@ -743,7 +743,7 @@ NoModule:  fprintf(err,_("\nType \"wp2latex -v\" to see a list of available modu
        }    	    
        
   logg = NULL;
-  if(log_filename != "")
+  if(!log_filename.isEmpty())
     {
     if(wpd_filename == log_filename)
       {
